# -*- coding: utf-8 -*-

from django.http import Http404
from django.shortcuts import render
from django.conf import settings
from django.urls import resolve

from .models import PageWeb


class PagesMiddleware(object):
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        response = self.get_response(request)

        if response.status_code != 404:
            return response

        peut_editer = request.user.is_authenticated and request.user.check_permission(request, "gerer_pages")

        adresse = request.path.lstrip("/")

        page, est_inp = self._get_page(request.ecole, adresse)
        proto = "https" if request.is_secure() else "http"

        if page is not None:
            c = {
                "peut_editer": peut_editer,
                "base_url": proto + "://" + settings.URLS_SITES[0] if est_inp else "",
                "page": page,
            }

            return render(request, "pages/affichage.html", c)

        try:
            match = resolve(request.path_info)
        except Http404:
            match = None

        if match is not None or not peut_editer:
            # La 404 vient d'une vue existante (donc qui pourrait devenir valide)
            # ou l'utilisateur n'a pas la permission d'éditer la page :
            # on renvoie la page 404 "normale"
            return response

        c = {
            "adresse": adresse,
        }

        return render(request, "pages/non_existante.html", c, status=404)

    @staticmethod
    def _get_page(ecole, adresse):
        try:
            page = PageWeb.objects.get(ecole=ecole, adresse=adresse)
            return page, False
        except PageWeb.DoesNotExist:
            pass

        try:
            page = PageWeb.objects.get(ecole__ident="inp", adresse=adresse)
            return page, True
        except PageWeb.DoesNotExist:
            pass

        return None, False
